@@ -37,6 +37,7 @@ IS_PYOPENSSL_SSL_VERSION_1_0 = (
     startswith(b'OpenSSL 1.0.')
 )
 PY27 = sys.version_info[:2] == (2, 7)
+PY34 = sys.version_info[:2] == (3, 4)
 
 
 _stdlib_to_openssl_verify = {
@@ -303,7 +304,7 @@ def test_tls_client_auth(
                     and tls_verify_mode == ssl.CERT_REQUIRED
                     and tls_client_identity == 'localhost'
                     and is_trusted_cert
-            ):
+            ) or PY34:
                 pytest.xfail(
                     'OpenSSL 1.0 has problems with verifying client certs',
                 )
@@ -311,18 +312,56 @@ def test_tls_client_auth(
             assert resp.text == 'Hello world!'
             return
 
-        with pytest.raises(requests.exceptions.SSLError) as ssl_err:
+        expected_ssl_errors = (
+            requests.exceptions.SSLError,
+            OpenSSL.SSL.Error,
+        ) if PY34 else (
+            requests.exceptions.SSLError,
+        )
+        if IS_WINDOWS:
+            expected_ssl_errors += requests.exceptions.ConnectionError,
+        with pytest.raises(expected_ssl_errors) as ssl_err:
             make_https_request()
 
-        err_text = ssl_err.value.args[0].reason.args[0].args[0]
+        if PY34 and isinstance(ssl_err, OpenSSL.SSL.Error):
+            pytest.xfail(
+                'OpenSSL behaves wierdly under Python 3.4 '
+                'because of an outdated urllib3',
+            )
 
-        expected_substring = (
+        try:
+            err_text = ssl_err.value.args[0].reason.args[0].args[0]
+        except AttributeError:
+            if PY34:
+                pytest.xfail('OpenSSL behaves wierdly under Python 3.4')
+            elif six.PY3 and IS_WINDOWS:
+                err_text = str(ssl_err.value)
+            else:
+                raise
+
+        expected_substrings = (
             'sslv3 alert bad certificate' if IS_LIBRESSL_BACKEND
-            else 'tlsv1 alert unknown ca'
+            else 'tlsv1 alert unknown ca',
         )
-        if IS_PYPY and six.PY3 and IS_MACOS and adapter_type == 'pyopenssl':
-            expected_substring = 'tlsv1 alert unknown ca'
-        assert expected_substring in err_text
+        if six.PY3:
+            if IS_MACOS and IS_PYPY and adapter_type == 'pyopenssl':
+                expected_substrings = ('tlsv1 alert unknown ca', )
+            if (
+                    IS_WINDOWS
+                    and tls_verify_mode in (
+                        ssl.CERT_REQUIRED,
+                        ssl.CERT_OPTIONAL,
+                    )
+                    and not is_trusted_cert
+                    and tls_client_identity == 'localhost'
+            ):
+                expected_substrings += (
+                    'bad handshake: '
+                    "SysCallError(10054, 'WSAECONNRESET')",
+                    "('Connection aborted.', "
+                    'OSError("(10054, \'WSAECONNRESET\')"))',
+                )
+        assert any(e in err_text for e in expected_substrings)
 
 
 @pytest.mark.parametrize(
