@@ -66,29 +66,31 @@ class WorkerThread(threading.Thread):
         self.work_time = 0
         self.stats = {
             'Requests': lambda s: self.requests_seen + (
-                (self.start_time is None) and
-                trueyzero or
-                self.conn.requests_seen
+                self.start_time is None
+                and trueyzero
+                or self.conn.requests_seen
             ),
             'Bytes Read': lambda s: self.bytes_read + (
-                (self.start_time is None) and
-                trueyzero or
-                self.conn.rfile.bytes_read
+                self.start_time is None
+                and trueyzero
+                or self.conn.rfile.bytes_read
             ),
             'Bytes Written': lambda s: self.bytes_written + (
-                (self.start_time is None) and
-                trueyzero or
-                self.conn.wfile.bytes_written
+                self.start_time is None
+                and trueyzero
+                or self.conn.wfile.bytes_written
             ),
             'Work Time': lambda s: self.work_time + (
-                (self.start_time is None) and
-                trueyzero or
-                time.time() - self.start_time
+                self.start_time is None
+                and trueyzero
+                or time.time() - self.start_time
             ),
             'Read Throughput': lambda s: s['Bytes Read'](s) / (
-                s['Work Time'](s) or 1e-6),
+                s['Work Time'](s) or 1e-6
+            ),
             'Write Throughput': lambda s: s['Bytes Written'](s) / (
-                s['Work Time'](s) or 1e-6),
+                s['Work Time'](s) or 1e-6
+            ),
         }
         threading.Thread.__init__(self)
 
@@ -132,7 +134,8 @@ class ThreadPool:
 
     def __init__(
             self, server, min=10, max=-1, accepted_queue_size=-1,
-            accepted_queue_timeout=10):
+            accepted_queue_timeout=10,
+    ):
         """Initialize HTTP requests queue instance.
 
         Args:
@@ -206,7 +209,7 @@ class ThreadPool:
         # Grow/shrink the pool if necessary.
         # Remove any dead threads from our list
         for t in self._threads:
-            if not t.isAlive():
+            if not t.is_alive():
                 self._threads.remove(t)
                 amount -= 1
 
@@ -239,7 +242,7 @@ class ThreadPool:
             endtime = time.time() + timeout
         while self._threads:
             worker = self._threads.pop()
-            if worker is not current and worker.isAlive():
+            if worker is not current and worker.is_alive():
                 try:
                     if timeout is None or timeout < 0:
                         worker.join()
@@ -247,7 +250,7 @@ class ThreadPool:
                         remaining_time = endtime - time.time()
                         if remaining_time > 0:
                             worker.join(remaining_time)
-                        if worker.isAlive():
+                        if worker.is_alive():
                             # We exhausted the timeout.
                             # Forcibly shut down the socket.
                             c = worker.conn
@@ -258,11 +261,13 @@ class ThreadPool:
                                     # pyOpenSSL sockets don't take an arg
                                     c.socket.shutdown()
                             worker.join()
-                except (AssertionError,
-                        # Ignore repeated Ctrl-C.
-                        # See
-                        # https://github.com/cherrypy/cherrypy/issues/691.
-                        KeyboardInterrupt):
+                except (
+                    AssertionError,
+                    # Ignore repeated Ctrl-C.
+                    # See
+                    # https://github.com/cherrypy/cherrypy/issues/691.
+                    KeyboardInterrupt,
+                ):
                     pass
 
     @property
